@@ -1,12 +1,12 @@
-/* 
+/*
  * GChemUtils GOffice component
- * gchemutils.h 
+ * gchemutils.h
  *
  * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -33,9 +33,9 @@ typedef struct _GOGChemUtilsComponent GOGChemUtilsComponent;
 
 typedef GOComponentClass GOGChemUtilsComponentClass;
 
-#define GO_GCHEMUTILS_COMPONENT_TYPE	(go_gchemutils_component_get_type ())
-#define GO_GCHEMUTILS_COMPONENT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GO_GCHEMUTILS_COMPONENT_TYPE, GOGChemUtilsComponent))
-#define GO_IS_GCHEMUTILS_COMPONENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_GCHEMUTILS_COMPONENT_TYPE))
+#define GO_TYPE_GCHEMUTILS_COMPONENT	(go_gchemutils_component_get_type ())
+#define GO_GCHEMUTILS_COMPONENT(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GO_TYPE_GCHEMUTILS_COMPONENT, GOGChemUtilsComponent))
+#define GO_IS_GCHEMUTILS_COMPONENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GO_TYPE_GCHEMUTILS_COMPONENT))
 
 GType go_gchemutils_component_get_type (void);
 
