@@ -156,6 +156,16 @@ GCCV_ITEM_POS_PROP (double, Width)
 /*!\fn GetFillColor()
 */
 GCCV_ITEM_PROP (GOColor, FillColor)
+/*!\fn SetAutoColor(bool auto)
+@param auto whether to use a color from the theme.
+
+if \a auto is true, the color used to draw the item will be retrieved from
+the Gtk+ theme instead of using the LineColor member.
+*/
+/*!\fn GetAutoColor()
+@return the line color mode, true if automatic, false otherwise.
+*/
+GCCV_ITEM_PROP (bool, AutoColor)
 };
 
 }
