@@ -1417,7 +1417,7 @@ void Atom::AddItem ()
 		char* markup = NULL;
 		char const *glyph = (charge > 0)? "\xE2\x8a\x95": "\xE2\x8a\x96";
 		if (abs (m_Charge) > 1)
-			markup = g_strdup_printf ("%d%s", abs (m_Charge), glyph);
+			markup = g_strdup_printf ("%d%s", static_cast < int > (abs (m_Charge)), glyph);
 		else
 			markup = g_strdup (glyph);
 		gccv::Text *text = new gccv::Text (group, x, y, this);
@@ -1451,7 +1451,7 @@ bool Atom::HasAvailableElectrons (bool paired)
 	while (obj) {
 		if ((electron = dynamic_cast <Electron *> (obj)))
 			break;
-			obj = GetNextChild (i);
+		obj = GetNextChild (i);
 	}
 	if (paired) {
 		if (m_nlp)
@@ -1514,6 +1514,34 @@ bool Atom::SetProperty (unsigned property, char const *value)
 	return  true;
 }
 
+std::string Atom::GetProperty (unsigned property) const
+{
+	std::ostringstream res;
+	switch (property) {
+	case GCU_PROP_TEXT_TEXT:
+		if (GetZ () != 6 || m_ShowSymbol) {
+			res << GetSymbol ();
+			if (m_nH > 0) {
+				res << "H";
+				if (m_nH > 1)
+					res << m_nH;
+			}
+		}
+		break;
+	case GCU_PROP_TEXT_POSITION:
+		if (GetZ () != 6 || m_ShowSymbol) {
+			gcu::Document const *doc = GetDocument ();
+			Theme *theme = static_cast < Document const * > (doc)->GetTheme ();
+			res << (m_x - m_width / 2. + theme->GetPadding () / theme->GetZoomFactor ()) / doc->GetScale ()
+				<< " " << (m_y + static_cast < Document const * > (doc)->GetView ()->GetCHeight ()) / doc->GetScale ();
+		}
+		break;
+	default:
+		return gcu::Atom::GetProperty (property);
+	}
+	return res.str ();
+}
+
 bool Atom::UpdateStereoBonds ()
 {
 	unsigned length[4]; // lengths before end or cycle 0 means cyclic bond
