@@ -48,6 +48,7 @@
 #include <list>
 #include <cmath>
 #include <cstring>
+#include <sstream>
 
 using namespace gcu;
 using namespace std;
@@ -347,6 +348,7 @@ bool Fragment::OnChanged (bool save)
 				m_EndAtom = CurPos;
 		}
 	}
+	m_Inversable = (m_BeginAtom == 0 || m_EndAtom == m_buf.size ()) && ((m_EndAtom - m_BeginAtom) < m_buf.length ());
 	gccv::Rect rect;
 	m_TextItem->GetPositionAtIndex (m_BeginAtom, rect);
 	m_lbearing = rect.x0;
@@ -394,6 +396,7 @@ void Fragment::AddItem ()
 {
 	if (m_Item)
 		return;
+	Update ();
 	Document *doc = static_cast <Document*> (GetDocument ());
 	View *view = doc->GetView ();
 	Theme *theme = doc->GetTheme ();
@@ -476,6 +479,7 @@ void Fragment::UpdateItem ()
 {
 	if (!m_TextItem)
 		return;
+	Update ();
 	Document *doc = static_cast <Document*> (GetDocument ());
 	View *view = doc->GetView ();
 	Theme *theme = doc->GetTheme ();
@@ -812,6 +816,7 @@ bool Fragment::Load (xmlNodePtr node)
 		}
 		m_TextItem->RebuildAttributes ();
 	}
+	m_Inversable = (m_BeginAtom == 0 || m_EndAtom == m_buf.size ()) && ((m_EndAtom - m_BeginAtom) < m_buf.length ());
 	m_bLoading = false;
 	pDoc->ObjectLoaded (this);
 	pDoc->ObjectLoaded (m_Atom);
@@ -1409,7 +1414,8 @@ bool Fragment::SetProperty (unsigned property, char const *value)
 	m_bLoading = true;
 	switch (property) {
 	case GCU_PROP_POS2D: {
-		sscanf (value, "%lg %lg", &m_x, &m_y);
+		std::istringstream str (value);
+		str >> m_x >> m_y;
 		gcu::Document *doc = GetDocument ();
 		if (doc) {
 			m_x *= doc->GetScale ();
@@ -1506,17 +1512,60 @@ bool Fragment::SetProperty (unsigned property, char const *value)
 	return true;
 }
 
+std::string Fragment::GetProperty (unsigned property) const
+{
+	switch (property) {
+	case GCU_PROP_POS2D: {
+		std::ostringstream str;
+		gcu::Document *doc = GetDocument ();
+		double scale = (doc)? doc->GetScale (): 1.;
+		str << m_x / scale << " " << m_y / scale;
+		return str.str ();
+	}
+	case GCU_PROP_X: {
+		std::ostringstream str;
+		gcu::Document *doc = GetDocument ();
+		double scale = (doc)? doc->GetScale (): 1.;
+		str << m_x / scale;
+		return str.str ();
+	}
+	case GCU_PROP_Y: {
+		std::ostringstream str;
+		gcu::Document *doc = GetDocument ();
+		double scale = (doc)? doc->GetScale (): 1.;
+		str << m_y / scale;
+		return str.str ();
+	}
+	case GCU_PROP_FRAGMENT_ATOM_START: {
+		std::ostringstream str;
+		str << m_BeginAtom;
+		return str.str ();
+	}
+	case GCU_PROP_FRAGMENT_ATOM_ID:
+		return m_Atom->GetId ();
+	case GCU_PROP_TEXT_POSITION: {
+		std::ostringstream str;
+		gcu::Document const *doc = GetDocument ();
+		Theme *theme = static_cast < Document const * > (doc)->GetTheme ();
+		str << (m_x - m_lbearing / theme->GetZoomFactor ()) / doc->GetScale ()
+				<< " " << (m_y + static_cast < Document const * > (doc)->GetView ()->GetCHeight ()) / doc->GetScale ();
+		return str.str ();
+	}
+	default:
+		break;
+	}
+	return TextObject::GetProperty (property);
+}
+
 bool Fragment::Analyze () {
 	// search if main atom is at start or at end
-	if ((m_BeginAtom == 0 || m_EndAtom == m_buf.size ()) && ((m_EndAtom - m_BeginAtom) < m_buf.length ()) ){
-		m_Inversable = true;
-	}
+	m_Inversable = (m_BeginAtom == 0 || m_EndAtom == m_buf.size ()) && ((m_EndAtom - m_BeginAtom) < m_buf.length ());
 //	int valence = m_Atom->GetValence ();
 	AnalContent ();
 	return true;
 }
 
-void Fragment::Update () {
+bool Fragment::Update () {
 	if (m_Atom->GetBondsNumber () > 0 && m_Inversable) {
 		map<gcu::Atom*, gcu::Bond*>::iterator i;
 		Bond *bond = reinterpret_cast <Bond *> (m_Atom->GetFirstBond (i));
@@ -1527,16 +1576,33 @@ void Fragment::Update () {
 			std::list<FormulaElt *> const &elts = formula->GetElements ();
 			m_buf.clear ();
 			std::list<FormulaElt *>::const_reverse_iterator i, end = elts.rend ();
-			for (i = elts.rbegin (); i!= end; i++) {
+			for (i = elts.rbegin (); i!= end; i++)
 				m_buf += (*i)->Text ();
-			}
 			delete formula;
 			m_EndAtom = m_buf.length ();
 			m_BeginAtom = m_EndAtom - strlen (m_Atom->GetSymbol ());
+			if (m_TextItem)
+				m_TextItem->ClearTags ();
+			else
+				m_TagList.clear ();
 			AnalContent ();
-		} else if (angle > 91. || angle < -91.) {
+			return true;
+		} else if (m_BeginAtom > 0 && (angle > 91. || angle < -91.)) {
+			// build the formula, then write elements in reverse order might be unsecure in some cases (if linked atom has a stoichiometric coefficient)
+			Formula *formula = new Formula (m_buf, GCU_FORMULA_PARSE_RESIDUE);
+			std::list<FormulaElt *> const &elts = formula->GetElements ();
+			m_buf.clear ();
+			std::list<FormulaElt *>::const_reverse_iterator i, end = elts.rend ();
+			for (i = elts.rbegin (); i!= end; i++)
+				m_buf += (*i)->Text ();
+			delete formula;
+			m_BeginAtom = 0;
+			m_EndAtom = strlen (m_Atom->GetSymbol ());
+			AnalContent ();
+			return true;
 		}
 	}
+	return false;
 }
 
 gccv::Item *Fragment::GetChargeItem ()
