@@ -122,6 +122,23 @@ mesomer at the other end of the arrow.
 @return th molecule associated with this mesomer.
 */
 	Molecule *GetMolecule () {return m_Molecule;}
+/*!
+@param property the identity of the property as defined in objprops.h.
+
+Used by the gcu::Loader mechanism to retrieve properties of mesomers.
+@return the value of the property as a string.
+*/
+	std::string GetProperty (unsigned property) const;
+/*!
+@param property the property id as defined in objprops.h
+@param value the property value as a string
+
+Used when loading to set common properties to mesomers. Only one property is
+currently supported: GCU_PROP_MESOMER.
+@return true if the property could be set, or if the property is not relevant,
+false otherwise.
+*/
+	bool SetProperty (unsigned property, char const *value);
 
 /*!
 @return the localized object generic name.
