@@ -259,7 +259,7 @@ bool Mesomery::Build (std::set < Object * > const &Children) throw (invalid_argu
 	return true;
 }
 
-static void BuildConnectivity ( set<Object *> &Objects, Mesomer* pMesomer)
+static void BuildConnectivity (set<Object *> &Objects, Mesomer* pMesomer)
 {
 	map<Mesomer *, MesomeryArrow *> *Arrows = pMesomer->GetArrows ();
 	map<Mesomer *, MesomeryArrow *>::iterator i, end = Arrows->end ();
@@ -753,7 +753,7 @@ void Mesomery::Transform2D (G_GNUC_UNUSED Matrix2D& m, G_GNUC_UNUSED double x, G
 bool Mesomery::OnSignal (G_GNUC_UNUSED SignalId Signal, G_GNUC_UNUSED Object *Child)
 {
 	Validate (true);
-	if (GetChildrenNumber () < 3)
+	if (GetChildrenNumber () < 3 || !Validate (true))
 		delete this;
 	else
 		Align ();
@@ -774,6 +774,8 @@ static void do_destroy_mesomery (void *data)
 
 bool Mesomery::BuildContextualMenu (gcu::UIManager *UIManager, Object *object, double x, double y)
 {
+	if (GetParentOfType (gcu::ReactionType) != NULL)
+		return false;
 	GtkUIManager *uim = static_cast < gcugtk::UIManager * > (UIManager)->GetUIManager ();
 	GtkActionGroup *group = gtk_action_group_new ("mesomery");
 	GtkAction *action = gtk_action_new ("destroy-ms", _("Destroy the mesomery relationship"), NULL, NULL);
