@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * preferences.h 
+ * preferences.h
  *
- * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -28,7 +28,7 @@
 /*!\file*/
 
 #include "fontsel.h"
-#include <gcu/dialog.h>
+#include <gcugtk/dialog.h>
 #include <gcu/object.h>
 #include <gcu/macros.h>
 
@@ -42,7 +42,7 @@ class Theme;
 \brief GChemPaint preferences dialog class
 */
 
-class PrefsDlg: public gcu::Dialog, gcu::Object
+class PrefsDlg: public gcugtk::Dialog, gcu::Object
 {
 friend class PrefsDlgPrivate;
 public:
@@ -101,7 +101,7 @@ private:
 	GcpFontSel *m_TextFontSel, *m_FontSel;
 	gulong m_NameActivate, m_NameFocusOut, m_TextFontChanged, m_FontChanged;
 	GtkTreePath *m_Path;
-	GtkComboBox *m_DefaultThemeBox;
+	GtkComboBoxText *m_DefaultThemeBox;
 };
 
 }	//	namespace gcp
