@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -26,6 +26,7 @@
 #define GCHEMPAINT_REACTANT_H
 
 #include <gcu/object.h>
+#include "text.h"
 
 /*!\file*/
 
@@ -120,14 +121,47 @@ coefficient does not need to be an integer, but should always be positive.
 */
 	void AddStoichiometry ();
 /*!
+@param stoichiometry: the text to use as stoichiometry coefficient.
+Adds a text item to display the reactants stoichiometry coefficient. This
+coefficient does not need to be an integer, but should always be positive.
+*/
+	void AddStoichiometry (gcp::Text *stoichiometry);
+/*!
 @return the molecule or text embedded in this instance.
 */
 	gcu::Object *GetChild () {return Child;}
 /*!
+@return the molecule or text embedded in this instance.
+*/
+	gcu::Object const *GetChild () const {return Child;}
+/*!
 @return the text representing the stoichiometry coefficient of this instance.
 */
 	gcu::Object *GetStoichChild () {return Stoichiometry;}
+/*!
+@param child: the reagent molecule
+Sets the reagent molecule.
+*/
+	void SetMolecule (gcu::Object *molecule);
+/*!
+@param property the identity of the property as defined in objprops.h.
 
+Used by the gcu::Loader mechanism to retrieve properties of mesomers.
+@return the value of the property as a string.
+*/
+	std::string GetProperty (unsigned property) const;
+/*!
+@param property the property id as defined in objprops.h
+@param value the property value as a string
+
+Used when loading to set common properties to mesomers. Currently supported
+property are:
+	GCU_PROP_STOICHIOMETRY,
+	GCU_PROP_MOLECULE.
+@return true if the property could be set, or if the property is not relevant,
+false otherwise.
+*/
+	bool SetProperty (unsigned property, char const *value);
 /*!
 @return the localized object generic name.
 */
