@@ -39,6 +39,7 @@
 #include <gcugtk/ui-manager.h>
 #include <gcu/objprops.h>
 #include <glib/gi18n-lib.h>
+#include <sstream>
 #include <cmath>
 #include <cstring>
 
@@ -377,6 +378,19 @@ bool ReactionArrow::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Child)
 	return true;
 }
 
+std::string ReactionArrow::GetProperty (unsigned property) const
+{
+	std::ostringstream res;
+	switch (property) {
+	case GCU_PROP_REACTION_ARROW_TYPE:
+		res << (m_Type == ReversibleArrow)? "double": "simple";
+		break;
+	default:
+		return Arrow::GetProperty (property);
+	}
+	return res.str ();
+}
+
 bool ReactionArrow::SetProperty (unsigned property, char const *value)
 {
 	switch (property) {
