@@ -125,11 +125,18 @@ It should not be called by a program; call Object::EmitSignal instead.
 */
 	bool OnSignal (gcu::SignalId Signal, gcu::Object *Child);
 /*!
+@param property the identity of the property as defined in objprops.h.
+
+Used by the gcu::Loader mechanism to retrieve properties of arrows.
+@return the value of the property as a string.
+*/
+	std::string GetProperty (unsigned property) const;
+/*!
 @param property the property id as defined in objprops.h
 @param value the property value as a string
 
 Used when loading to set common properties to arrows. Only one property is
-currently supported: gcu::GCU_PROP_REACTION_ARROW_TYPE.
+currently supported: GCU_PROP_REACTION_ARROW_TYPE.
 @return true if the property could be set, or if the property is not relevant,
 false otherwise.
 */
