@@ -139,6 +139,30 @@ It should not be called by a program; call Object::EmitSignal instead.
 @return true to be propagate the signal to the parent.
 */
 	bool OnSignal (gcu::SignalId Signal, gcu::Object *Child);
+/*!
+@param property the property id as defined in objprops.h
+
+Used when saving to get properties from a reaction operator.
+Currently supported properties:
+	GCU_PROP_ARROW_OBJECT.
+@return the value of the property as a string.
+*/
+	std::string GetProperty (unsigned property) const;
+/*!
+@param property the property id as defined in objprops.h
+@param value the property value as a string
+
+Used when loading to set common properties to arrow associated objects.
+
+@return true if the property could be set, or if the property is not relevant,
+false otherwise.
+*/
+	bool SetProperty (unsigned property, char const *value);
+/*!
+@param child: the embedded object
+Sets the rembedded objecte.
+*/
+	void SetChild (gcu::Object *child);
 
 /*!
 @return the localized object generic name.
