@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -43,6 +43,7 @@ using namespace std;
 namespace gcp {
 
 TypeId ReactionStepType = NoType;
+TypeId DummyStepType = NoType;
 
 ReactionStep::ReactionStep (): MechanismStep (ReactionStepType)
 {
@@ -160,6 +161,7 @@ void ReactionStep::OnLoaded ()
 	double x, y, x0, y0, x1, y1;
 	// this method is called more than once (might consider this a bug) so we need to remove old operators
 	std::list <gcu::Object *> Operators;
+	// FIXME: add a dummy object if empty
 	while (pObj) {
 		if (pObj->GetType () == ReactionOperatorType)
 			Operators.push_front (pObj);
@@ -183,18 +185,15 @@ void ReactionStep::OnLoaded ()
 	x = rect.x1;
 	y = (*im).second->GetYAlign ();
 	for (im++; im != endm; im++) {
-		x += pTheme->GetSignPadding ();
+		pObj = (*im).second;
+		rect = Objects[pObj];
+		x = (x + rect.x0) / 2.;
 		//Add a sign
 		ReactionOperator* pOp = new ReactionOperator();
 		AddChild (pOp);
 		pOp->SetCoords(x / pTheme->GetZoomFactor (), y);
 		pDoc->AddObject(pOp);
-		dynamic_cast <gccv::ItemClient *> (pOp)->GetItem ()->GetBounds (x0, y0, x1, y1);
-		pOp->Move ((x - x0) / pTheme->GetZoomFactor (), 0);
-		x += pTheme->GetSignPadding () + x1 - x0;
-		pObj = (*im).second;
-		rect = Objects[pObj];
-		x+= rect.x1 - rect.x0;
+		x= rect.x1;
 	}
 	m_bLoading = false;
 }
@@ -226,11 +225,18 @@ bool ReactionStep::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Child)
 		map<double, Object*>::iterator im, endm;
 		double x, y, x0, y0, x1, y1;
 		std::set <gcu::Object *> Invalid;
+		if (!pObj) {
+			delete this;
+			return true;
+		}
 		while (pObj) {
 			if (pObj->GetType () == ReactionOperatorType)
 				Operators.push_front (pObj);
 			else if (pObj->GetType () == MechanismArrowType); // don't do anything
-			else {
+			else if (pObj->GetType () == MesomeryArrowType) {
+				delete this;
+				return true;
+			} else {
 				if (pObj->GetChildrenNumber ()) {
 					pData->GetObjectBounds (pObj, &rect);
 					x = (rect.x0 + rect.x1) / 2;
@@ -283,14 +289,6 @@ bool ReactionStep::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Child)
 		return true;
 }
 
-void ReactionStep::RemoveArrow (ReactionArrow *arrow) {
-	m_Arrows.erase (arrow);
-	if (m_Arrows.empty ()) {
-		// if there is no more arrows this is no more a reaction step
-		delete this;
-	}
-}
-
 std::string ReactionStep::Name ()
 {
 	return _("Reaction step");
@@ -298,9 +296,9 @@ std::string ReactionStep::Name ()
 
 void ReactionStep::CleanChildren ()
 {
-	set<ReactionArrow *>::iterator i, end = m_Arrows.end();
+	map < Step *, Arrow * >::iterator i, end = m_Arrows.end();
 	for (i = m_Arrows.begin (); i != end; i++)
-		(*i)->RemoveStep (this);
+		(*i).second->RemoveStep (this);
 	/* If there are no chidren, don't care and exit */
 	if (!GetChildrenNumber ())
 		return;
@@ -325,7 +323,7 @@ void ReactionStep::CleanChildren ()
 			Child->SetParent (pObj);
 			arrows.push_back (static_cast <MechanismArrow *> (Child));
 			continue;
-		} else if (Child->GetType () == MechanismStepType) {
+		} else if (Child->GetType () == MechanismStepType || Child->GetType () == MesomeryArrowType) {
 			Child->SetParent (pObj);
 			if (pOp && !Group)
 				new_objects.insert (Child);
@@ -393,4 +391,12 @@ void ReactionStep::AddMolecule (Molecule *molecule, bool signal)
 		EmitSignal (OnChangedSignal);
 }
 
+bool ReactionStep::Validate ()
+{
+	if (m_Arrows.empty ())
+		return false;
+	// FIXME:
+	return true;
+}
+
 }	//	namespace gcp
