@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -98,20 +98,6 @@ It should not be called by a program; call Object::EmitSignal instead.
 */
 	bool OnSignal (gcu::SignalId Signal, gcu::Object *Child);
 
-/*!
-@param arrow an arrow related to this instance.
-
-Adds an arrow to the list of arrows related to this instance.
-*/
-	void AddArrow (ReactionArrow *arrow) {m_Arrows.insert (arrow);}
-/*!
-@param arrow an arrow related to this instance.
-
-Removes an arrow from the list of arrows related to this instance when it
-not anymore relevant.
-*/
-	void RemoveArrow (ReactionArrow *arrow);
-
 /*!
 @return the localized object generic name.
 */
@@ -120,17 +106,23 @@ not anymore relevant.
 @param molecule a molecule.
 @param signal wheter to emit the \a OnChangedSignal
 
-Adds amolecue to this step.
+Adds a molecule to this step.
 */
 	void AddMolecule (Molecule *molecule, bool signal = true);
-	 void OnLoaded ();
+/*!
+*/
+	void OnLoaded ();
+/*!
+@return true if there is at least one arrow associated with this step if the
+step is not empty of if there are non consecutive arrows around.
+*/
+	bool Validate ();
 
 private:
 	void CleanChildren ();
 
 private:
 	bool m_bLoading;
-	std::set<ReactionArrow *> m_Arrows;
 };
 
 }	//	namespace gcp
