@@ -4,11 +4,11 @@
  * GChemPaint library
  * step.h
  *
- * Copyright (C) 2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2011-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -38,10 +38,22 @@ objects and arrows between them.
 class Scheme: public gcu::Object
 {
 public:
+/*!
+@param type the actual type of the object.
+
+The default constructor.
+*/
 	Scheme (gcu::TypeId type);
+
+/*!
+The destructor.
+*/
 	virtual ~Scheme ();
 
 protected:
+/*!
+Aligns the children logically.
+*/
 	void Align () throw (std::invalid_argument);
 };
 
