@@ -39,6 +39,7 @@
 #include <gcu/objprops.h>
 #include <gcu/xml-utils.h>
 #include <glib/gi18n-lib.h>
+#include <sstream>
 #include <stdexcept>
 #include <cmath>
 #include <cstring>
@@ -53,6 +54,7 @@ Text::Text ():
 	m_Anchor (gccv::AnchorLineWest),
 	m_GlobalTag (gccv::Invalid),
 	m_Interline (0.),
+	m_VariableLineHeight (true),
 	m_Justification (GTK_JUSTIFY_LEFT)
 {
 }
@@ -62,6 +64,7 @@ Text::Text (double x, double y):
 	m_Anchor (gccv::AnchorLineWest),
 	m_GlobalTag (gccv::Invalid),
 	m_Interline (0.),
+	m_VariableLineHeight (true),
 	m_Justification (GTK_JUSTIFY_LEFT)
 {
 }
@@ -71,6 +74,7 @@ Text::Text (gccv::Tag tag, double x, double y):
 	m_Anchor (gccv::AnchorLineWest),
 	m_GlobalTag (tag),
 	m_Interline (0.),
+	m_VariableLineHeight (true),
 	m_Justification (GTK_JUSTIFY_LEFT)
 {
 }
@@ -167,7 +171,7 @@ bool SaveStruct::Save (xmlDocPtr xml, xmlNodePtr node, unsigned &index, string c
 		f = static_cast <gccv::FamilyTextTag *> (m_tag)->GetFamily ().c_str ();
 		ef = m_end;
 		if (es >= ef) {
-			char *str = g_strdup_printf ("%s %g", f, (double) n / PANGO_SCALE);
+			char *str = g_strdup_printf ("%s, %g", f, (double) n / PANGO_SCALE);
 			child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("font"), NULL);
 			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("name"), reinterpret_cast <xmlChar const *> (str));
 			g_free (str);
@@ -177,7 +181,7 @@ bool SaveStruct::Save (xmlDocPtr xml, xmlNodePtr node, unsigned &index, string c
 		n = static_cast <gccv::SizeTextTag *> (m_tag)->GetSize ();
 		es = m_end;
 		if (ef >= es) {
-			char *str = g_strdup_printf ("%s %g", f, (double) n / PANGO_SCALE);
+			char *str = g_strdup_printf ("%s, %g", f, (double) n / PANGO_SCALE);
 			child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("font"), NULL);
 			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("name"), reinterpret_cast <xmlChar const *> (str));
 			g_free (str);
@@ -926,8 +930,10 @@ void Text::AddItem ()
 
 void Text::UpdateItem ()
 {
-	if (!m_Item)
+	if (!m_Item) {
+		AddItem ();
 		return;
+	}
 	Document *doc = static_cast <Document*> (GetDocument ());
 	Theme *theme = doc->GetTheme ();
 	reinterpret_cast <gccv::Text *> (m_Item)->SetPosition (m_x * theme->GetZoomFactor (), m_y * theme->GetZoomFactor ());
@@ -995,12 +1001,94 @@ double Text::GetYAlign ()
 	return m_y;
 }
 
+std::string Text::GetProperty (unsigned property) const
+{
+	switch (property) {
+	case GCU_PROP_POS2D: {
+		std::ostringstream str;
+		gcu::Document *doc = GetDocument ();
+		str.precision (12);
+		if (doc)
+			str << m_x / doc->GetScale () << " " << m_y / doc->GetScale ();
+		else
+			str << m_x << " " << m_y;
+		return str.str ();
+	}
+	case GCU_PROP_TEXT_MARKUP: {
+		xmlDocPtr xml = xmlNewDoc ((xmlChar*) "1.0");
+		char *buf;
+		int n;
+		//FIXME: do something if an error occurs
+
+		xmlFreeNode (xmlDocSetRootElement (xml,  Save (xml)));
+		xmlDocDumpMemory (xml, reinterpret_cast < xmlChar ** > (&buf), &n);
+		std::string res (buf, n);
+		xmlFree (buf);
+		xmlFreeDoc (xml);
+		return res;
+
+	}
+	case GCU_PROP_TEXT_TEXT:
+		return m_buf;
+	case GCU_PROP_TEXT_ALIGNMENT:
+		switch (m_Anchor) {
+		case gccv::AnchorLineEast:
+		case gccv::AnchorNorthEast:
+		case gccv::AnchorEast:
+		case gccv::AnchorSouthEast:
+			return "right";
+		case gccv::AnchorNorthWest:
+		case gccv::AnchorLineWest:
+		case gccv::AnchorWest:
+		case gccv::AnchorSouthWest:
+			return "left";
+		case gccv::AnchorNorth:
+		case gccv::AnchorLine:
+		case gccv::AnchorCenter:
+		case gccv::AnchorSouth:
+			return "center";
+		}
+		break;
+	case GCU_PROP_TEXT_JUSTIFICATION:
+		switch (m_Justification) {
+		case GTK_JUSTIFY_RIGHT:
+			return  "right";
+		case GTK_JUSTIFY_LEFT:
+			return  "left";
+		case GTK_JUSTIFY_CENTER:
+			return  "center";
+		case GTK_JUSTIFY_FILL:
+			return "justify";
+		}
+		break;
+	case GCU_PROP_TEXT_INTERLINE: {
+		std::ostringstream str;
+		str << m_Interline;
+		return str.str ();
+	}
+	case GCU_PROP_TEXT_MAX_LINE_HEIGHT: {
+		std::ostringstream str;
+		if (m_TextItem)
+			str << m_TextItem->GetMaxLineHeight ();
+		else {
+			Theme *theme = static_cast < Document * > (GetDocument ())->GetTheme ();
+			str << static_cast < double > (theme->GetTextFontSize ()) / PANGO_SCALE;
+		}
+		return str.str ();
+	}
+	case GCU_PROP_TEXT_VARIABLE_LINE_HEIGHT:
+		return m_VariableLineHeight? "true": "false";
+	}
+	return "";
+}
+
 bool Text::SetProperty (unsigned property, char const *value)
 {
 	switch (property) {
 	case GCU_PROP_POS2D: {
+		std::istringstream str (value);
 		double x, y;
-		sscanf (value, "%lg %lg", &x, &y);
+		str >> x >> y;
 		gcu::Document *doc = GetDocument ();
 		if (doc) {
 			x *= doc->GetScale ();
@@ -1011,6 +1099,8 @@ bool Text::SetProperty (unsigned property, char const *value)
 	}
 	case GCU_PROP_TEXT_MARKUP: {
 		xmlDocPtr xml = xmlParseMemory (value, strlen (value));
+		if (xml == NULL)
+			break;
 		xmlNodePtr node = xml->children->children;
 		unsigned pos = 0;
 		m_buf.clear ();
@@ -1022,6 +1112,7 @@ bool Text::SetProperty (unsigned property, char const *value)
 		}
 		m_bLoading = false;
 		// FIXME: implement
+		xmlFreeDoc (xml);
 		break;
 	}
 	case GCU_PROP_TEXT_TEXT:
@@ -1045,6 +1136,14 @@ bool Text::SetProperty (unsigned property, char const *value)
 		else if (!strcmp (value, "justify"))
 				m_Justification = GTK_JUSTIFY_FILL;
 		break;
+	case GCU_PROP_TEXT_INTERLINE: {
+		std::istringstream str (value);
+		str >> m_Interline;
+		break;
+	}
+	case GCU_PROP_TEXT_VARIABLE_LINE_HEIGHT:
+		m_VariableLineHeight = !strcmp (value, "true");
+		break;
 	}
 	return true;
 }
