@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -613,6 +613,9 @@ bool Theme::Save (xmlDocPtr xml)
 	case PANGO_WEIGHT_LIGHT:
 		buf = "light";
 		break;
+	case PANGO_WEIGHT_SEMILIGHT:
+		buf = "semi-light";
+		break;
 	case PANGO_WEIGHT_NORMAL:
 		buf = "normal";
 		break;
@@ -702,6 +705,9 @@ bool Theme::Save (xmlDocPtr xml)
 	case PANGO_WEIGHT_LIGHT:
 		buf = "light";
 		break;
+	case PANGO_WEIGHT_SEMILIGHT:
+		buf = "semi-light";
+		break;
 	case PANGO_WEIGHT_NORMAL:
 		buf = "normal";
 		break;
@@ -823,6 +829,8 @@ bool Theme::Load (xmlNodePtr node)
 			m_FontWeight= PANGO_WEIGHT_ULTRALIGHT;
 		else if (!strcmp (buf, "light"))
 			m_FontWeight = PANGO_WEIGHT_LIGHT;
+		else if (!strcmp (buf, "semi-light"))
+			m_FontWeight = PANGO_WEIGHT_SEMILIGHT;
 		else if (!strcmp (buf, "normal"))
 			m_FontWeight = PANGO_WEIGHT_NORMAL;
 		else if (!strcmp (buf, "semi-bold"))
@@ -899,6 +907,8 @@ bool Theme::Load (xmlNodePtr node)
 			m_TextFontWeight= PANGO_WEIGHT_ULTRALIGHT;
 		else if (!strcmp (buf, "light"))
 			m_TextFontWeight = PANGO_WEIGHT_LIGHT;
+		else if (!strcmp (buf, "semi-light"))
+			m_TextFontWeight = PANGO_WEIGHT_SEMILIGHT;
 		else if (!strcmp (buf, "normal"))
 			m_TextFontWeight = PANGO_WEIGHT_NORMAL;
 		else if (!strcmp (buf, "semi-bold"))
