@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * tool.h 
+ * tool.h
  *
- * Copyright (C) 2001-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -35,6 +35,7 @@
 namespace gcu {
 	class Dialog;
 	class Object;
+	class UIManager;
 }
 
 namespace gccv {
@@ -50,7 +51,7 @@ class WidgetData;
 class Operation;
 
 /*!\class Tool
-Base clas for GChemPaint tools.	
+Base clas for GChemPaint tools.
 */
 class Tool
 {
@@ -66,7 +67,7 @@ Constructs a new tool.
 The destructor.
 */
 	virtual ~Tool ();
-	
+
 /*!
 @param pView the view instance owning the event.
 @param pObject the Object on which the click occured.
@@ -127,21 +128,21 @@ is released.
 @param pObject the object on which the event occured.
 @param x the horizontal position of the mouse when the event occured.
 @param y the vertical position of the mouse when the event occured.
-@param UIManager the GtkUIManager in use.
+@param UIManager the gcu::UIManager in use.
 
 This method is called by the framework when the tool is active and the right mouse button
 is pressed. It is used to add tool specific menu items to the contextual menu.
-It calls OnRightButtonClicked(GtkUIManager*).
+It calls OnRightButtonClicked(gcu::UIManager*).
 
 @return true if at least one menu item was added, false otherwise.
 */
-	bool OnRightButtonClicked (View* pView, gcu::Object* pObject, double x, double y, GtkUIManager *UIManager);
+	bool OnRightButtonClicked (View* pView, gcu::Object* pObject, double x, double y, gcu::UIManager *UIManager);
 /*!
 @param bState whether to activate or deactivate the tool.
 
 When \a bState is true, the tool is activated, otherwise it is deactivated.
 Activate() or Deactivate() is called for this instance.
-@return true on success, and false otherwise. Activation always succeeds. 
+@return true on success, and false otherwise. Activation always succeeds.
 */
 	bool Activate (bool bState);
 /*!
@@ -149,14 +150,14 @@ Activate() or Deactivate() is called for this instance.
 */
 	std::string& GetName () {return name;}
 /*!
-@param UIManager the GtkUIManager in use.
+@param UIManager the gcu::UIManager in use.
 
 Adds menu items to the contextual menu.
 Default implementation do not add any menu item and returns false. Derived classes
 for which menu items exist must override this method.
 @return true if at least one menu item was added, false otherwise.
 */
-	virtual bool OnRightButtonClicked (GtkUIManager *UIManager);
+	virtual bool OnRightButtonClicked (gcu::UIManager *UIManager);
 /*!
 Virtual method called when the tool is activated.
 This method should be overriden for all tools which need some initialization
@@ -339,12 +340,12 @@ y coordinate for the last mouse click (unless the tool modified it).
 	double m_y0;
 /*!
 x coordinate for the last mouse click (unless the tool modified it). It might
-be used by tools necessitating to pairs of coordinates.
+be used by tools necessitating two pairs of coordinates.
 */
 	double m_x1;
 /*!
 y coordinate for the last mouse click (unless the tool modified it). It might
-be used by tools necessitating to pairs of coordinates.
+be used by tools necessitating two pairs of coordinates.
 */
 	double m_y1;
 /*!
@@ -411,6 +412,12 @@ private:
 	std::string name;
 	bool m_bPressed;
 
+/*!\var m_OwnStatus
+Whether the tool owns the status bar text.
+*/
+/*!\fn GetOwnStatus()
+@return whether the tool owns the status bar text.
+*/
 GCU_PROT_PROP (bool, OwnStatus)
 };
 
