@@ -29,6 +29,7 @@
 #include "tools.h"
 #include <gcugtk/ui-manager.h>
 #include <gcu/element.h>
+#include <glib/gi18n-lib.h>
 #include <cstring>
 
 using namespace gcu;
@@ -51,31 +52,110 @@ static void help_cb (Tools *box)
 	box->OnHelp ();
 }
 
-Tools::Tools (Application *App):
-	gcugtk::Dialog (App, UIDIR"/tools.ui", "tools", GETTEXT_PACKAGE, App),
-	m_UIManager (NULL)
+class Toolbar {
+public:
+	Toolbar ();
+
+	GtkToolbar *bar;
+	std::vector < unsigned > sections;
+};
+
+Toolbar::Toolbar ():
+	bar (NULL)
 {
-	g_signal_connect (G_OBJECT (dialog), "delete-event", G_CALLBACK (on_delete_event), NULL);
-	Application *pApp = dynamic_cast<Application*> (App);
-	m_UIManager = NULL;
+}
+
+static void tool_toggled_cb (GtkToggleToolButton *btn, Application *app)
+{
+	if (gtk_toggle_tool_button_get_active (btn))
+		app->OnToolChanged (gtk_widget_get_name (GTK_WIDGET (btn)));
+}
+
+Tools::Tools (Application *app, std::list < ToolDesc const * > const &descs):
+	gcugtk::Dialog (app, UIDIR"/tools.ui", "tools", GETTEXT_PACKAGE, app),
+	m_Parent (NULL)
+{
+	std::list < ToolDesc const * >::const_iterator d, end = descs.end ();
+	std::vector < Toolbar > toolbars;
+	int i;
+	GtkToolItem *btn;
+	GSList *group = NULL;
 	m_ButtonsGrid = GTK_GRID (GetWidget ("tools-buttons"));
+	toolbars.resize (MaxToolbar);
+	for (i = 0; i < MaxToolbar; i++) {
+		GtkWidget *bar = gtk_toolbar_new ();
+		toolbars[i].bar = GTK_TOOLBAR (bar);
+		gtk_toolbar_set_style (toolbars[i].bar, GTK_TOOLBAR_ICONS);
+		gtk_toolbar_set_show_arrow (toolbars[i].bar, false);
+		gtk_container_add (GTK_CONTAINER (m_ButtonsGrid), bar);
+	}
+	for (d = descs.begin(); d != end; d++) {
+		ToolDesc const *desc = *d;
+		while (desc->name != NULL) {
+			bool separator = false;
+			if (!strcmp (desc->name, "Separator"))
+				separator = true;
+			else if (desc->widget == NULL && desc->icon_name == NULL) {
+				desc++;
+				continue;
+			}
+			if (separator)
+				btn = gtk_separator_tool_item_new ();
+			else {
+				btn = gtk_radio_tool_button_new (group);
+				group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (btn));
+
+				GtkWidget *w;
+				if (desc->widget) {
+					w = desc->widget;
+					gtk_widget_set_size_request (w, 24, 24);
+				} else
+					w = gtk_image_new_from_icon_name (desc->icon_name, GTK_ICON_SIZE_LARGE_TOOLBAR);
+				gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (btn), w);
+				gtk_widget_set_name (GTK_WIDGET (btn), desc->name);
+				g_signal_connect (G_OBJECT (btn), "toggled", G_CALLBACK (tool_toggled_cb), app);
+				gtk_tool_item_set_tooltip_text (btn, _(desc->tip));
+				app->SetToolItem (desc->name, reinterpret_cast < GtkWidget * > (btn));
+				m_Pages[app->GetTool (desc->name)] = -1;
+				m_Widgets[desc->name] = reinterpret_cast < GtkWidget * > (btn);
+			}
+			unsigned n = toolbars[desc->bar].sections.size (), p;
+			if (n < desc->group) {
+				toolbars[desc->bar].sections.resize (desc->group);
+				p = gtk_toolbar_get_n_items (toolbars[desc->bar].bar);
+				while (n < desc->group) {
+					toolbars[desc->bar].sections[n] = p;
+					n++;
+				}
+			}
+			if (desc->group == toolbars[desc->bar].sections.size ())
+				i = -1;
+			else {
+				i = toolbars[desc->bar].sections[p = desc->group];
+				n = toolbars[desc->bar].sections.size ();
+				while (p < n)
+					toolbars[desc->bar].sections[p++]++;
+			}
+			gtk_toolbar_insert (toolbars[desc->bar].bar,  btn, i);
+			desc++;
+		}
+	}
+	gtk_widget_show_all (GTK_WIDGET (m_ButtonsGrid));
 	m_Book = GTK_NOTEBOOK (GetWidget ("tools-book"));
 	GtkWidget *grid = GetWidget ("element-grid");
 	GtkWidget *w = gcu_combo_periodic_new ();
 	m_Mendeleiev = reinterpret_cast <GcuComboPeriodic *> (w);
 	gtk_container_add (GTK_CONTAINER (grid), w);
-	gcu_combo_periodic_set_element (GCU_COMBO_PERIODIC (w), pApp->GetCurZ ());
+	gcu_combo_periodic_set_element (GCU_COMBO_PERIODIC (w), app->GetCurZ ());
 	g_signal_connect_swapped (G_OBJECT (w), "changed", G_CALLBACK (element_changed_cb), this);
 	w = GetWidget ("help-btn");
 	g_signal_connect_swapped (G_OBJECT (w), "clicked", G_CALLBACK (help_cb), this);
+	g_signal_connect (G_OBJECT (dialog), "delete-event", G_CALLBACK (on_delete_event), NULL);
+	gtk_widget_show_all (GTK_WIDGET (dialog));
 }
 
 Tools::~Tools ()
 {
-	if (m_UIManager) {
-		delete m_UIManager;
-		m_UIManager = NULL;
-	}
 }
 
 void Tools::Show (bool visible)
@@ -94,26 +174,6 @@ void register_item_cb (GtkWidget *w, Tools *Dlg)
 	Dlg->RegisterTool (w);
 }
 
-void Tools::AddToolbar (string &name)
-{
-	if (m_UIManager) {
-		GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), name.c_str ()),
-			*h = gtk_handle_box_new ();
-		g_object_set (G_OBJECT (h), "hexpand", true, NULL);
-		gtk_container_foreach (GTK_CONTAINER (w), (GtkCallback) register_item_cb, this);
-		gtk_toolbar_set_style (GTK_TOOLBAR (w), GTK_TOOLBAR_ICONS);
-		gtk_toolbar_set_show_arrow (GTK_TOOLBAR (w), false);
-		gtk_container_add (GTK_CONTAINER (h), w);
-		gtk_container_add (GTK_CONTAINER (m_ButtonsGrid), h);
-		gtk_widget_show_all (h);
-	}
-}
-
-void Tools::SetUIManager (gcugtk::UIManager *manager)
-{
-	m_UIManager = manager;
-}
-
 void Tools::SetPage (Tool *tool, int i)
 {
 	m_Pages[tool] = i;
@@ -121,6 +181,11 @@ void Tools::SetPage (Tool *tool, int i)
 
 void Tools::OnSelectTool (Tool *tool)
 {
+	// make sure that the button is checked
+	std::string &name = tool->GetName ();
+	GtkToggleToolButton *btn = reinterpret_cast < GtkToggleToolButton * > (m_Widgets[name]);
+	if (!gtk_toggle_tool_button_get_active (btn))
+		gtk_toggle_tool_button_set_active (btn, true);
 	if (m_Pages[tool] < 0) {
 		GtkWidget *w = tool->GetPropertyPage ();
 		if (w)
@@ -147,7 +212,7 @@ void Tools::OnElementChanged (int Z)
 {
 	dynamic_cast<Application*> (m_App)->SetCurZ (Z);
 	// Hmm, we should find a better way to do the following, the path might change.
-	GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "ui/AtomsToolbar/Atom1/Element");
+	GtkWidget *w = m_Widgets["Element"];
 	if (!w)
 		return;
 	GtkWidget* icon = gtk_tool_button_get_icon_widget (GTK_TOOL_BUTTON (w));
