@@ -45,10 +45,11 @@ class Tools: public gcugtk::Dialog
 public:
 /*!
 @param App the GChemPaint Application.
+@param descs the tools description.
 
 Builds the tools box for the application.
 */
-	Tools (Application *App);
+	Tools (Application *app, std::list < ToolDesc const * > const &descs);
 /*!
 The destructor.
 */
@@ -113,12 +114,13 @@ Called by the framework when the Help button is clicked.
 	void OnHelp ();
 
 private:
-	gcugtk::UIManager *m_UIManager;
 	GtkGrid *m_ButtonsGrid;
-	std::map<Tool*, int> m_Pages;
+	std::map < Tool *, int > m_Pages;
+	std::map < std::string, GtkWidget *> m_Widgets;
 	GtkNotebook *m_Book;
 	Tool *m_Tool;
 	GcuComboPeriodic *m_Mendeleiev;
+	GtkWindow *m_Parent;
 };
 
 }	// namespace gcp
