@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * zoomdlg.cc 
+ * zoomdlg.cc
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -33,12 +33,12 @@
 using namespace gcu;
 
 namespace gcp {
-	
+
 static void on_focus_in (ZoomDlg *dlg)
 {
 	dlg->OnFocusIn ();
 }
-	
+
 static void on_zoom_changed (GtkSpinButton *btn, gcp::Document *pDoc)
 {
 	View *pView = pDoc->GetView ();
@@ -47,22 +47,18 @@ static void on_zoom_changed (GtkSpinButton *btn, gcp::Document *pDoc)
 }
 
 ZoomDlg::ZoomDlg (gcp::Document *pDoc):
-	Dialog (pDoc->GetApplication (), GLADEDIR"/zoom.glade", "zoomdlg", pDoc)
+	gcugtk::Dialog (pDoc->GetApplication (), UIDIR"/zoom.ui", "zoomdlg", GETTEXT_PACKAGE, pDoc)
 {
-	if (!xml) {
-		delete this;
-		return;
-	}
 	g_signal_connect_swapped (G_OBJECT (dialog), "focus_in_event", G_CALLBACK (on_focus_in), this);
-	btn = (GtkSpinButton*) glade_xml_get_widget (xml, "zoom");
-	m_ZoomSignal = g_signal_connect_swapped (G_OBJECT (btn), "value-changed", G_CALLBACK (on_zoom_changed), pDoc);
+	btn = GTK_SPIN_BUTTON (GetWidget ("zoom"));
+	m_ZoomSignal = g_signal_connect (G_OBJECT (btn), "value-changed", G_CALLBACK (on_zoom_changed), pDoc);
 	m_Doc = pDoc;
 }
 
 ZoomDlg::~ZoomDlg ()
 {
 }
-	
+
 void ZoomDlg::OnFocusIn ()
 {
 	if (!m_Doc)
