@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -65,6 +65,7 @@ public:
 	static void ValueChanged (AtomsDlg *pBox, unsigned row, unsigned column);
 	static void RowSelected (AtomsDlg *pBox, int row);
 	static void ElementChanged (AtomsDlg *pBox, unsigned Z);
+	static void SetElement (unsigned i, AtomsDlg *pBox);
 	static void ColorSet (GtkColorButton *btn, AtomsDlg *pBox);
 	static void SetColor (unsigned i, AtomsDlg *pBox);
 	static void ColorToggled (GtkToggleButton *btn, AtomsDlg *pBox);
@@ -207,9 +208,16 @@ void AtomsDlgPrivate::RowSelected (AtomsDlg *pBox, int row)
 	}
 }
 
+void AtomsDlgPrivate::SetElement (unsigned i, AtomsDlg *pBox)
+{
+	pBox->m_Atoms[i]->SetZ (pBox->m_nElt);
+	gcr_grid_set_string (pBox->m_Grid, i, 0, pBox->m_nElt > 0? Element::GetElement (pBox->m_nElt)->GetSymbol (): _("Unknown"));
+	pBox->m_Atoms[i]->SetRadius (pBox->m_Radius);
+	pBox->m_Atoms[i]->SetColor (pBox->m_RGBA.red, pBox->m_RGBA.green, pBox->m_RGBA.blue, pBox->m_RGBA.alpha);
+}
+
 void AtomsDlgPrivate::ElementChanged (AtomsDlg *pBox, unsigned Z)
 {
-	GdkRGBA color;
 	if ((pBox->m_nElt = Z)) {
 		pBox->m_Radii = Element::GetElement (Z)->GetRadii ();
 		if ((pBox->m_RadiusType == GCU_IONIC) && (pBox->m_Charge == 0)) {
@@ -219,21 +227,17 @@ void AtomsDlgPrivate::ElementChanged (AtomsDlg *pBox, unsigned Z)
 			pBox->PopulateRadiiMenu ();
 		gtk_toggle_button_set_active (pBox->CustomColor, false);
 		double *Colors = Element::GetElement (Z)->GetDefaultColor ();
-		color.red = Colors[0];
-		color.green = Colors[1];
-		color.blue = Colors[2];
-		color.alpha = 1.;
-		gtk_color_button_set_rgba (pBox->AtomColor, &color);
+		pBox->m_RGBA.red = Colors[0];
+		pBox->m_RGBA.green = Colors[1];
+		pBox->m_RGBA.blue = Colors[2];
+		pBox->m_RGBA.alpha = 1.;
+		gtk_color_button_set_rgba (pBox->AtomColor, &pBox->m_RGBA);
 	} else {
 		pBox->m_Radii = NULL;
 		gtk_toggle_button_set_active (pBox->CustomColor, true);
-		gtk_color_button_get_rgba (pBox->AtomColor, &color);
 	}
 	if (pBox->m_AtomSelected >= 0) {
-		pBox->m_Atoms[pBox->m_AtomSelected]->SetZ (Z);
-		gcr_grid_set_string (pBox->m_Grid, pBox->m_AtomSelected, 0, Z > 0? Element::GetElement (Z)->GetSymbol (): _("Unknown"));
-		pBox->m_Atoms[pBox->m_AtomSelected]->SetRadius (pBox->m_Radius);
-		pBox->m_Atoms[pBox->m_AtomSelected]->SetColor (color.red, color.green, color.blue, color.alpha);
+		gcr_grid_for_each_selected (pBox->m_Grid, reinterpret_cast < GridCb > (SetElement), pBox);
 		pBox->m_pDoc->Update ();
 		pBox->m_pDoc->SetDirty (true);
 	}
@@ -241,7 +245,7 @@ void AtomsDlgPrivate::ElementChanged (AtomsDlg *pBox, unsigned Z)
 
 void AtomsDlgPrivate::SetColor (unsigned i, AtomsDlg *pBox)
 {
-		pBox->m_Atoms[i]->SetColor (pBox->m_RGBA.red, pBox->m_RGBA.green, pBox->m_RGBA.blue, pBox->m_RGBA.alpha);
+	pBox->m_Atoms[i]->SetColor (pBox->m_RGBA.red, pBox->m_RGBA.green, pBox->m_RGBA.blue, pBox->m_RGBA.alpha);
 }
 
 void AtomsDlgPrivate::ColorSet (GtkColorButton *btn, AtomsDlg *pBox)
@@ -374,13 +378,11 @@ void AtomsDlgPrivate::SetRadius (unsigned i, AtomsDlg *pBox)
 
 bool AtomsDlgPrivate::RadiusEdited (AtomsDlg *pBox)
 {
-	if (pBox->m_Radius.type != GCU_RADIUS_UNKNOWN)
-		return false; // don't care
 	g_signal_handler_block (pBox->AtomR, pBox->m_EntryFocusOutSignalID);
 	if (pBox->GetNumber (pBox->AtomR, &(pBox->m_Radius.value.value), gcugtk::Min, 0) && pBox->m_AtomSelected >= 0) {
-/*		gcr_grid_for_each_selected (pBox->m_Grid, reinterpret_cast < GridCb > (SetRadius), pBox);
+		gcr_grid_for_each_selected (pBox->m_Grid, reinterpret_cast < GridCb > (SetRadius), pBox);
 		pBox->m_pDoc->Update ();
-		pBox->m_pDoc->SetDirty (true);*/
+		pBox->m_pDoc->SetDirty (true);
 	}
 	g_signal_handler_unblock (pBox->AtomR, pBox->m_EntryFocusOutSignalID);
 	return false;
@@ -510,15 +512,15 @@ void AtomsDlg::PopulateRadiiMenu ()
 			j++;
 			radius++;
 		}
+	g_signal_handler_unblock (RadiusMenu, m_RadiiSignalID);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (RadiusMenu), selected);
 	gtk_widget_set_sensitive (SelectEltBtn, m_nElt > 0);
-	g_signal_handler_unblock (RadiusMenu, m_RadiiSignalID);
 	m_Radius.charge = m_Charge;
 }
 
 void AtomsDlg::Closed ()
 {
-	// check if the cleavages list is coherent
+	// check if the atoms list is coherent
 	m_Closing = true;
 	m_pDoc->CheckAtoms ();
 }
