@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -29,6 +29,7 @@
 #include "grid.h"
 #include <vector>
 
+/*!\file*/
 namespace gcu {
 class Application;
 }
@@ -39,16 +40,36 @@ class Document;
 class Application;
 class Cleavage;
 
+/*!\class CleavagesDlg gcr/cleavagesdlg.h
+\brief GCrystal cleavages dialog class.
+
+This class wraps the dialog used to define cleavages inside a crystal model.
+*/
 class CleavagesDlg: public gcugtk::Dialog
 {
 friend class CleavagesDlgPrivate;
 public:
+/*!
+@param App the application running the dialog.
+@param pDoc the document.
+
+Creates the dialog.
+*/
 	CleavagesDlg (gcr::Application *App, gcr::Document* pDoc);
+/*!
+The destructor.
+*/
 	virtual ~CleavagesDlg ();
 
-	void Closed ();
+/*!
+Reloads the cleavages list from the document. The list might have changed after
+simplification following duplicates detection.
+*/
 	void ReloadData ();
 
+private:
+	void Closed ();
+
 private:
 	Document *m_pDoc;
 	std::vector < Cleavage * > m_Cleavages;
