@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -48,8 +48,10 @@ public:
 	static void AddRow (LinesDlg *pBox);
 	static void DeleteRow (LinesDlg *pBox);
 	static void DeleteAll (LinesDlg *pBox);
+	static void SelectAll (LinesDlg *pBox);
 	static void ValueChanged (LinesDlg *pBox, unsigned row, unsigned column);
 	static void RowSelected (LinesDlg *pBox, int row);
+	static void RowDeleted (LinesDlg *pBox, int row);
 	static void EdgesToggled (GtkToggleButton *btn, LinesDlg *pBox);
 	static void DiagonalsToggled (GtkToggleButton *btn, LinesDlg *pBox);
 	static void MediansToggled (GtkToggleButton *btn, LinesDlg *pBox);
@@ -60,7 +62,9 @@ public:
 	static void DiagsColorSet (GtkColorButton *btn, LinesDlg *pBox);
 	static void MediansColorSet (GtkColorButton *btn, LinesDlg *pBox);
 	static bool RadiusEdited (LinesDlg *pBox);
+	static void SetRadius (unsigned i, LinesDlg *pBox);
 	static void ColorSet (GtkColorButton *btn, LinesDlg *pBox);
+	static void SetColor (unsigned i, LinesDlg *pBox);
 };
 
 void LinesDlgPrivate::AddRow (LinesDlg *pBox)
@@ -91,13 +95,7 @@ void LinesDlgPrivate::AddRow (LinesDlg *pBox)
 
 void LinesDlgPrivate::DeleteRow (LinesDlg *pBox)
 {
-	pBox->m_pDoc->GetLineList ()->remove (pBox->m_Lines[pBox->m_LineSelected]);
-	delete pBox->m_Lines[pBox->m_LineSelected];
-	pBox->m_Lines.erase (pBox->m_Lines.begin () + pBox->m_LineSelected);
-	gcr_grid_delete_row (GCR_GRID (pBox->m_Grid), pBox->m_LineSelected);
-	pBox->m_pDoc->Update ();
-	pBox->m_pDoc->SetDirty (true);
-	gtk_widget_set_sensitive (pBox->DeleteAllBtn, !pBox->m_pDoc->GetLineList ()->empty ());
+	gcr_grid_delete_selected_rows (GCR_GRID (pBox->m_Grid));
 }
 
 void LinesDlgPrivate::DeleteAll (LinesDlg *pBox)
@@ -112,6 +110,11 @@ void LinesDlgPrivate::DeleteAll (LinesDlg *pBox)
 	gtk_widget_set_sensitive (pBox->DeleteAllBtn, false);
 }
 
+void LinesDlgPrivate::SelectAll (LinesDlg *pBox)
+{
+	gcr_grid_select_all (pBox->m_Grid);
+}
+
 void LinesDlgPrivate::ValueChanged (LinesDlg *pBox, unsigned row, unsigned column)
 {
 	double coord = column != COLUMN_SINGLE? gcr_grid_get_double (pBox->m_Grid, row, column): 0.;
@@ -158,6 +161,16 @@ void LinesDlgPrivate::RowSelected (LinesDlg *pBox, int row)
 	}
 }
 
+void LinesDlgPrivate::RowDeleted (LinesDlg *pBox, int row)
+{
+	pBox->m_pDoc->GetLineList ()->remove (pBox->m_Lines[row]);
+	delete pBox->m_Lines[row];
+	pBox->m_Lines.erase (pBox->m_Lines.begin () + row);
+	pBox->m_pDoc->Update ();
+	pBox->m_pDoc->SetDirty (true);
+	gtk_widget_set_sensitive (pBox->DeleteAllBtn, !pBox->m_pDoc->GetLineList ()->empty ());
+}
+
 void LinesDlgPrivate::EdgesToggled (GtkToggleButton *btn, LinesDlg *pBox)
 {
 	bool active = gtk_toggle_button_get_active (btn);
@@ -287,25 +300,33 @@ void LinesDlgPrivate::MediansColorSet (GtkColorButton *btn, LinesDlg *pBox)
 	pBox->m_pDoc->SetDirty (true);
 }
 
+void LinesDlgPrivate::SetRadius (unsigned i, LinesDlg *pBox)
+{
+		pBox->m_Lines[i]->SetRadius (pBox->m_Radius);
+}
+
 bool LinesDlgPrivate::RadiusEdited (LinesDlg *pBox)
 {
 	g_signal_handler_block (pBox->LineR, pBox->m_LineFocusOutSignalID);
-	double r;
-	if (pBox->m_LineSelected >= 0 && pBox->GetNumber (pBox->LineR, &r, gcugtk::Min, 0)) {
-			pBox->m_Lines[pBox->m_LineSelected]->SetRadius (r);
-			pBox->m_pDoc->Update ();
-			pBox->m_pDoc->SetDirty (true);
+	if (pBox->m_LineSelected >= 0 && pBox->GetNumber (pBox->LineR, &pBox->m_Radius, gcugtk::Min, 0)) {
+		gcr_grid_for_each_selected (pBox->m_Grid, reinterpret_cast < GridCb > (SetRadius), pBox);
+		pBox->m_pDoc->Update ();
+		pBox->m_pDoc->SetDirty (true);
 	}
 	g_signal_handler_unblock (pBox->LineR, pBox->m_LineFocusOutSignalID);
 	return false;
 }
 
+void LinesDlgPrivate::SetColor (unsigned i, LinesDlg *pBox)
+{
+		pBox->m_Lines[i]->SetColor (pBox->m_rgba);
+}
+
 void LinesDlgPrivate::ColorSet (GtkColorButton *btn, LinesDlg *pBox)
 {
 	if (pBox->m_LineSelected >= 0) {
-		GdkRGBA rgba;
-		gtk_color_button_get_rgba (btn, &rgba);
-		pBox->m_Lines[pBox->m_LineSelected]->SetColor (rgba);
+		gtk_color_button_get_rgba (btn, &pBox->m_rgba);
+		gcr_grid_for_each_selected (pBox->m_Grid, reinterpret_cast < GridCb > (SetColor), pBox);
 		pBox->m_pDoc->Update ();
 		pBox->m_pDoc->SetDirty (true);
 	}
@@ -322,13 +343,16 @@ LinesDlg::LinesDlg (Application *App, Document* pDoc): gcugtk::Dialog (App, UIDI
 	g_signal_connect_swapped (G_OBJECT (DeleteBtn), "clicked", G_CALLBACK (LinesDlgPrivate::DeleteRow), this);
 	DeleteAllBtn = GetWidget ("delete-all");
 	g_signal_connect_swapped (G_OBJECT (DeleteAllBtn), "clicked", G_CALLBACK (LinesDlgPrivate::DeleteAll), this);
+	g_signal_connect_swapped (GetObject ("select-all"), "clicked", G_CALLBACK (LinesDlgPrivate::SelectAll), this);
 	m_Grid = GCR_GRID (gcr_grid_new (_("x1"), G_TYPE_DOUBLE, _("y1"), G_TYPE_DOUBLE, _("z1"), G_TYPE_DOUBLE,
 	                                 _("x2"), G_TYPE_DOUBLE, _("y2"), G_TYPE_DOUBLE, _("z2"), G_TYPE_DOUBLE,
 	                                 _("Single"), G_TYPE_BOOLEAN, NULL));
+	gcr_grid_set_allow_multiple_selection (m_Grid, true);
 	g_object_set (G_OBJECT (m_Grid), "expand", true, NULL);
 	gtk_grid_attach (GTK_GRID (GetWidget ("other-grid")), GTK_WIDGET (m_Grid), 0, 1, 4, 5);
 	g_signal_connect_swapped (G_OBJECT (m_Grid), "row-selected", G_CALLBACK (LinesDlgPrivate::RowSelected), this);
 	g_signal_connect_swapped (G_OBJECT (m_Grid), "value-changed", G_CALLBACK (LinesDlgPrivate::ValueChanged), this);
+	g_signal_connect_swapped (G_OBJECT (m_Grid), "row-deleted", G_CALLBACK (LinesDlgPrivate::RowDeleted), this);
 	EdgesBtn = GTK_CHECK_BUTTON (GetWidget ("edges"));
 	EdgesColor = GTK_COLOR_BUTTON (GetWidget ("edges-color"));
 	gtk_widget_set_sensitive (GTK_WIDGET (EdgesColor), false);
