@@ -4,11 +4,11 @@
  * Gnome Crystal
  * prefs.h
  *
- * Copyright (C) 2001-2011 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2012 Jean Brfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -27,15 +27,29 @@
 
 #include <gcugtk/dialog.h>
 
+/*!\file*/
 namespace gcr {
 
 class Application;
 
+/*!\class PrefsDlg gcr/prefs.h
+\brief Application preferences dialog class.
+
+This class wraps the dialog used to define the preferences of the application.
+*/
 class PrefsDlg: public gcugtk::Dialog
 {
 friend class PrefsDlgPrivate;
 public:
+/*!
+@param App the application.
+
+Creates the dialog.
+*/
 	PrefsDlg (Application *App);
+/*!
+The destructor.
+*/
 	virtual ~PrefsDlg ();
 
 private:
