@@ -70,12 +70,12 @@ Application::Application (string name, string datadir, char const *help_name, ch
 	char const *szlang = getenv ("LANG");
 	string lang = (szlang)? szlang: "C";
 	HelpName = help_name? help_name: Name;
-	HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("-"API_VERSION"/") + lang + string ("/") + HelpName + "-"API_VERSION".xml";
+	HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("-" API_VERSION "/") + lang + string ("/") + HelpName + "-" API_VERSION ".xml";
 	GFile *file = g_file_new_for_uri (HelpFilename.c_str ());
 	bool exists = g_file_query_exists (file, NULL);
 	g_object_unref (file);
 	if (!exists) {
-		HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("-"API_VERSION"/C/") + HelpName + "-"API_VERSION".xml";
+		HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("-" API_VERSION "/C/") + HelpName + "-" API_VERSION ".xml";
 	}
 	HelpBrowser = "yelp"; // there is no more key for that
 	char *dir = g_get_current_dir ();
@@ -527,11 +527,12 @@ char const *Application::MimeToBabelType (char const *mime_type)
 	return (it == m_BabelTypes.end ())? mime_type: (*it).second.c_str ();
 }
 
-
+#define MAX_ATTEMPTS 10
 int Application::OpenBabelSocket ()
 {
 	struct stat statbuf;
 	static std::string socket_path = "/tmp/babelsocket-";
+	unsigned n = 0;
 	if (socket_path.length () == 17)
 		socket_path += getenv ("USER");
 	if (stat (socket_path.c_str (), &statbuf)) {
@@ -556,9 +557,12 @@ int Application::OpenBabelSocket ()
 	struct sockaddr_un adr_serv;
 	adr_serv.sun_family = AF_UNIX;
 	strcpy (adr_serv.sun_path, socket_path.c_str ());
-	if (connect (res, (const struct sockaddr*) &adr_serv, sizeof (struct sockaddr_un)) == -1) {
+	while (connect (res, (const struct sockaddr*) &adr_serv, sizeof (struct sockaddr_un)) == -1) {
 		perror (_("Connection failed"));
-		return -1;
+		n++;
+		if (n == MAX_ATTEMPTS)
+			return -1;
+		sleep (1);
 	}
 	return res;
 }
@@ -602,7 +606,7 @@ char* Application::ConvertToCML (std::string const &uri, const char *mime_type,
 		GError *error = NULL;
 		GFileInfo *info = g_file_query_info (file,
 											 ((mime_type)? G_FILE_ATTRIBUTE_STANDARD_SIZE:
-											 G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE","G_FILE_ATTRIBUTE_STANDARD_SIZE),
+											 G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE "," G_FILE_ATTRIBUTE_STANDARD_SIZE),
 											 G_FILE_QUERY_INFO_NONE,
 											 NULL, &error);
 		if (error) {
