@@ -48,7 +48,7 @@ char const *gcu_element_get_name (int Z)
 	return Element::GetElement (Z)->GetName ();
 }
 
-int gcu_element_get_Z (char* symbol)
+int gcu_element_get_Z (char const *symbol)
 {
 	return Element::Z (symbol);
 }
@@ -167,6 +167,12 @@ char *gcu_element_get_weight_as_string (int Z)
 		return NULL;
 }
 
+double gcu_element_get_weight (int Z)
+{
+	Element *elt = Element::GetElement (Z);
+	return elt? elt->GetWeight ()->GetAsDouble (): 0.;
+}
+
 char const *gcu_element_get_electronic_configuration (int Z)
 {
 	Element *elt = Element::GetElement (Z);
