@@ -206,7 +206,7 @@ gcu_element_get_Z:
 \param symbol: the symbol of the element (e.g. "C" ot "Pt").
 \return the atomic number of the element.
 */
-int gcu_element_get_Z (char* symbol);
+int gcu_element_get_Z (char const *symbol);
 /*!
 \param radius: a pointer to a GcuAtomicRadius structure.
 
@@ -270,6 +270,12 @@ char *gcu_element_get_weight_as_string (int Z);
 /*!
 \param Z: the atomic number.
 
+\return the atomic weight.
+*/
+double gcu_element_get_weight (int Z);
+/*!
+\param Z: the atomic number.
+
 \return the electronic configuration as a pango markup.
 */
 char const *gcu_element_get_electronic_configuration (int Z);
