@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
  * gcu/dialog-owner.cc
  *
  * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -40,13 +40,13 @@ DialogOwner::~DialogOwner ()
 	ClearDialogs ();
 }
 
-Dialog *DialogOwner::GetDialog (string name)
+Dialog *DialogOwner::GetDialog (string name) const
 {
-	map <string, Dialog *>::iterator i = Dialogs.find (name);
+	map <string, Dialog *>::const_iterator i = Dialogs.find (name);
 	return (i != Dialogs.end ())? (*i).second: NULL;
 }
 
-bool DialogOwner::AddDialog (string name, Dialog *dialog) 
+bool DialogOwner::AddDialog (string name, Dialog *dialog)
 {
 	if (Dialogs[name]) {
 		Dialogs[name]->Present ();
