@@ -132,11 +132,11 @@ A Matrix reprenting the scene spatial orientation
 */
 	Matrix m_Euler;
 /*!
-A matrix 
+The mouse cursor last horizontal position. 
 */
 	double m_Lastx;
 /*!
-A Matrix 
+The mouse cursor last vertical position. 
 */
 	double m_Lasty;
 /*!
