@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -56,7 +56,11 @@ Spectral data.
 /*!
 Miscalleneous contents. Might include anything.
 */
-	ContentTypeMisc
+	ContentTypeMisc,
+/*!
+Invalid data.
+*/
+	ContentTypeInvalid
 } ContentType;
 
 }   //  namespace gcu
