@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -44,8 +44,18 @@ The destructor.
 */
 	virtual ~Window ();
 
+/*!
+@param title the new title.
+
+Sets the window title.
+*/
 	void SetTitle (char const *title) {gtk_window_set_title (m_Window, title);}
 
+/*!
+@eturn the screen where the window is displayed.
+*/
+	GdkScreen *GetScreen () {return gtk_widget_get_screen (GTK_WIDGET (GetWindow ()));}
+
 /*!\var m_Window
 The GtkWindow instance corresponding to the Window.
 */
