@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * CIF files loader plugin
- * cif.cc 
+ * cif.cc
  *
- * Copyright (C) 2008-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2008-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -51,13 +51,14 @@ public:
 	virtual ~CIFLoader ();
 
 	ContentType Read (Document *doc, GsfInput *in, char const *mime_type, GOIOContext *io);
-	bool Write (Object *obj, GsfOutput *out, char const *mime_type, GOIOContext *io, ContentType type);
+	bool Write (Object const *obj, GsfOutput *out, char const *mime_type, GOIOContext *io, ContentType type);
 };
 
 enum { // local only properties
 	CIF_ATOM_SITE_SYMBOL = GCU_PROP_MAX + 1,
 	CIF_ATOM_SITE_OXIDATION_NUMBER,
-	CIF_ATOM_LABEL
+	CIF_ATOM_LABEL,
+	CIF_TRANSFORM
 };
 
 CIFLoader::CIFLoader ()
@@ -72,7 +73,7 @@ CIFLoader::CIFLoader ()
 	KnownProps["_cell_length_a"] = GCU_PROP_CELL_A;
 	KnownProps["_cell_length_b"] = GCU_PROP_CELL_B;
 	KnownProps["_cell_length_c"] = GCU_PROP_CELL_C;
-	KnownProps["_cell_angle_apha"] = GCU_PROP_CELL_ALPHA;
+	KnownProps["_cell_angle_alpha"] = GCU_PROP_CELL_ALPHA;
 	KnownProps["_cell_angle_beta"] = GCU_PROP_CELL_BETA;
 	KnownProps["_cell_angle_gamma"] = GCU_PROP_CELL_GAMMA;
 
@@ -89,6 +90,9 @@ CIFLoader::CIFLoader ()
 	KnownProps["_atom_site_fract_y"] = GCU_PROP_YFRACT;
 	KnownProps["_atom_site_fract_z"] = GCU_PROP_ZFRACT;
 	KnownProps["_atom_site_aniso_label"] = CIF_ATOM_LABEL;
+
+	KnownProps["_symmetry_equiv_pos_as_xyz"] = CIF_TRANSFORM;
+	KnownProps["_space_group_symop_operation_xyz"] = CIF_TRANSFORM;
 }
 
 CIFLoader::~CIFLoader ()
@@ -117,7 +121,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 	Application *app = doc->GetApplication ();
 	GsfInputTextline *input = reinterpret_cast <GsfInputTextline *> (gsf_input_textline_new (in));
 	char *buf;
-	bool in_string = false, in_loop = false, waiting_value = false;
+	bool in_string = false, in_loop = false, waiting_value = false, empty = true;
 	string key, value;
 	int size;
 	char endstr = 0;
@@ -137,7 +141,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 		size = strlen (buf);
 		// check for new data bloc
 		if (!strncmp (cur, "data_", 5)) {
-			if (!doc->GetEmpty ())
+			if (!empty)
 				// FIXME: implement multiple data blocs reading
 				goto read_exit;
 		}
@@ -189,7 +193,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 				next = cur;
 				while (*next && *next != ' ')
 					next++;
-					
+
 				*next = 0;
 				key = cur;
 				cur = next + 1;
@@ -207,7 +211,10 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 								loop_type = LOOP_ATOM;
 							else if (!key.compare (0, 13, "_publ_author_",13))
 								loop_type = LOOP_AUTHOR;
-							else if (key == "_symmetry_equiv_pos_as_xyz")
+							else if (key == "_symmetry_equiv_pos_as_xyz" ||
+							         key == "_symmetry_equiv_pos_site_id" ||
+							         key == "_space_group_symop_operation_xyz" ||
+							         key == "_space_group_symop_id")
 								loop_type = LOOP_SYMMETRY;
 						}
 					} else {
@@ -278,6 +285,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 										} else {
 											LabeledAtoms[val] = atom;
 											doc->AddChild (atom);
+											empty = false;
 										}
 										if (AtomTypes.empty ()) {
 											int i = 0;
@@ -382,7 +390,11 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 								break;
 							}
 							case LOOP_SYMMETRY: {
-								group->AddTransform (loop_values.front ());
+								for (loop_prop = loop_contents.begin (); loop_prop != loop_contents.end (); loop_prop++) {
+									if (*loop_prop == CIF_TRANSFORM)
+										group->AddTransform (loop_values.front ());
+									loop_values.pop_front ();
+								}
 								break;
 							}
 							}
@@ -503,19 +515,19 @@ typedef struct
 {
 	string symbol;
 	string label;
-	string XFract, YFract, ZFract; 
+	string XFract, YFract, ZFract;
 } AtomInstance;
 
-bool CIFLoader::Write  (G_GNUC_UNUSED Object *obj, GsfOutput *out, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED GOIOContext *io, G_GNUC_UNUSED ContentType type)
+bool CIFLoader::Write  (G_GNUC_UNUSED Object const *obj, GsfOutput *out, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED GOIOContext *io, G_GNUC_UNUSED ContentType type)
 {
 	std::string prop;
 	unsigned i;
 	if (NULL != out) {
-		Document *doc = dynamic_cast <Document *> (obj);
+		Document const *doc = dynamic_cast <Document const *> (obj);
 		if (!doc)
 			doc = obj->GetDocument ();
 		if (doc)
-			doc->SetScale (100);
+			const_cast <Document *> (doc)->SetScale (100);
 		prop = obj->GetProperty (GCU_PROP_DOC_TITLE);
 		if (prop.length () == 0)
 			prop = "0";
@@ -568,14 +580,13 @@ bool CIFLoader::Write  (G_GNUC_UNUSED Object *obj, GsfOutput *out, G_GNUC_UNUSED
 			}
 		}
 		// iterate through the children and prepare atoms export
-		map <string, Object *>::iterator i;
-		Object *child = doc->GetFirstChild (i);
+		map <string, Object *>::const_iterator i;
+		Object const *child = doc->GetFirstChild (i);
 		map <string, Atom_Type> AtomTypes;
 		list <AtomInstance> AtomInstances;
 		map <int, int> types;
 		map <int, int> indices;
 		map <string, Atom_Type>::iterator t, tend;
-		char *buf;
 		while (child) {
 			// FIXME, using gcu::Atom is not conform to the spirit of the loader mechanism
 			if (child->GetType () == AtomType) {
@@ -600,7 +611,6 @@ bool CIFLoader::Write  (G_GNUC_UNUSED Object *obj, GsfOutput *out, G_GNUC_UNUSED
 					ostringstream str;
 					str << index;
 					type.symbol = symbol + str.str ();
-					g_free (buf);
 					type.charge = charge;
 					AtomTypes[id] = type;
 					instance.symbol = type.symbol;
@@ -637,7 +647,7 @@ bool CIFLoader::Write  (G_GNUC_UNUSED Object *obj, GsfOutput *out, G_GNUC_UNUSED
 				+ (*n).ZFract + "\n";
 			gsf_output_write (out, prop.length (), reinterpret_cast <guint8 const *> (prop.c_str ()));
 		}
-		
+
 		return true;
 	}
 	return false;
