@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint atoms plugin
- * elementtool.cc 
+ * elementtool.cc
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -53,7 +53,7 @@ bool gcpElementTool::OnClicked ()
 	int CurZ = m_pApp->GetCurZ ();
 	if (m_pObject) {
 		if (m_pObject->GetType () != AtomType)
-			return false; 
+			return false;
 		if 	(((gcp::Atom*) m_pObject)->GetTotalBondsNumber () > (int) Element::GetMaxBonds (CurZ))
 			return false;
 		((gcp::Atom*) m_pObject)->GetCoords (&m_x0, &m_y0);
@@ -67,7 +67,8 @@ bool gcpElementTool::OnClicked ()
 	text->SetText (symbol);
 	text->SetFontDescription (m_pView->GetPangoFontDesc ());
 	text->SetPadding (m_pView->GetDoc ()->GetTheme ()->GetPadding ());
-	text->SetFillColor (gcp::AddColor);
+	text->SetFillColor (0);
+	text->SetColor (gcp::AddColor);
 	text->SetLineOffset (m_pView->GetCHeight ());
 	text->GetPosition (m_x1, m_y1, m_x2, m_y2);
 	m_x2 += m_x1;
@@ -110,17 +111,17 @@ void gcpElementTool::OnRelease ()
 				gcp::Atom* pNewAtom = new gcp::Atom (CurZ, x, y, 0.);
 				pMol->Remove (parent);
 				m_pView->Remove (parent);
-				m_pView->AddObject (pNewAtom);
-				parent->SetParent (NULL);
 				pMol->AddAtom (pNewAtom);
+				parent->SetParent (NULL);
 				pNewAtom->SetId ((gchar*) pAtom->GetId ());
 				if (pBond) {
 					pBond->ReplaceAtom (pAtom, pNewAtom);
 					pNewAtom->AddBond (pBond);
+					pBond->SetDirty ();
 					m_pView->Update (pBond);
 				}
 				pNewAtom->Update ();
-				m_pView->Update (pNewAtom);
+				m_pView->AddObject (pNewAtom);
 				delete parent;
 			} else {
 				gcp::Atom* pAtom = static_cast <gcp::Atom *> (m_pObject);
@@ -132,8 +133,8 @@ void gcpElementTool::OnRelease ()
 					pBond->SetDirty ();
 					m_pView->Update (pBond);
 					pBond = (gcp::Bond*) pAtom->GetNextBond (i);
-				}	
-			}	
+				}
+			}
 			pOp->AddObject (pObj, 1);
 		} else {
 			gcp::Atom* pAtom = new gcp::Atom (CurZ, m_x0 / m_dZoomFactor, m_y0 / m_dZoomFactor, 0);
