@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint residues plugin
- * plugin.cc 
+ * plugin.cc
  *
- * Copyright (C) 2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -30,6 +30,7 @@
 #include <gcp/document.h>
 #include <gcp/molecule.h>
 #include <gcp/residue.h>
+#include <gcugtk/ui-manager.h>
 #include <glib/gi18n-lib.h>
 #include <sys/stat.h>
 #include <cstring>
@@ -61,7 +62,7 @@ static void on_new_residue (gcp::Residue *res)
 	plugin.OnNewResidue (res);
 }
 
-static GOptionEntry options[] = 
+static GOptionEntry options[] =
 {
   {"edit-residue", 'e', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) on_edit_residues, "Open residues dialog", NULL},
   {NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
@@ -83,21 +84,22 @@ static const char *ui_description =
 "  </menubar>"
 "</ui>";
 
-static void on_menu (GtkUIManager *UIManager)
+static void on_menu (gcu::UIManager *UIManager)
 {
+	GtkUIManager *uim = static_cast < gcugtk::UIManager * > (UIManager)->GetUIManager ();
 	GtkActionGroup *action_group = gtk_action_group_new ("ResiduesActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), NULL);
 
-	gtk_ui_manager_insert_action_group (UIManager, action_group, 1);
+	gtk_ui_manager_insert_action_group (uim, action_group, 1);
 	g_object_unref (action_group);
-	gtk_ui_manager_add_ui_from_string (UIManager, ui_description, -1, NULL);
+	gtk_ui_manager_add_ui_from_string (uim, ui_description, -1, NULL);
 }
 
 void gcpResiduesPlugin::Populate (gcp::Application *App)
 {
-	// Load the residues databases
-	PseudoAtomType = Object::AddType ("pseudo-atom", CreatePseudoAtom);
+	m_App = App;
+	PseudoAtomType = App->AddType ("pseudo-atom", CreatePseudoAtom);
 	xmlDocPtr doc;
 	xmlNodePtr node;
 	char *name;
@@ -126,9 +128,6 @@ void gcpResiduesPlugin::Populate (gcp::Application *App)
 			ParseNodes (node->children, true);
 	}
 	g_free (name);
-
-	// populate the tools box
-	m_App = App;
 	App->RegisterOptions (options);
 	App->AddMenuCallback (on_menu);
 	gcp::Residue::SetPostAddCallback (on_new_residue);
@@ -137,9 +136,9 @@ void gcpResiduesPlugin::Populate (gcp::Application *App)
 void gcpResiduesPlugin::OpenDialog ()
 {
 	Dialog *dlg = m_App->GetDialog ("residues");
-	if (dlg) 
-		gtk_window_present (dlg->GetWindow ());
-	else 
+	if (dlg)
+		dlg->Present ();
+	else
 		new gcpResiduesDlg (m_App);
 }
 
@@ -149,7 +148,7 @@ void gcpResiduesPlugin::ParseNodes (xmlNodePtr node, bool writeable)
 	while (node) {
 		if (!strcmp ((char*) node->name, "residue")) {
 			r = new gcp::Residue ();
-			r->Load (node, !writeable);
+			r->Load (node, !writeable, m_App);
 		}
 		node = node->next;
 	}
@@ -197,7 +196,7 @@ void gcpResiduesPlugin::OnNewResidue (gcp::Residue *res)
 			xmlKeepBlanksDefault (0);
 			xmlSaveFormatFile ((char*) user_residues->URL, user_residues, true);
 			xmlFreeDoc (xml);
-			res->Load (node, false);
+			res->Load (node, false, m_App);
 		}
 	}
 	if (dlg)
