@@ -6,7 +6,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -42,10 +42,14 @@ TypeId GroupType = NoType;
 
 static void on_group_properties (gcpGroup* group)
 {
-	new gcpGroupDlg ((gcp::Document*) group->GetDocument (), group);
+	Dialog *dlg = group->GetDialog ("group");
+	if (dlg)
+		dlg->Present ();
+	else
+		new gcpGroupDlg ((gcp::Document*) group->GetDocument (), group);
 }
 
-gcpGroup::gcpGroup (): Object(GroupType)
+gcpGroup::gcpGroup (): Object(GroupType), DialogOwner ()
 {
 	SetId ("gr1");
 	m_Align = false;
@@ -377,10 +381,7 @@ void gcpGroup::OnLoaded ()
 	for (child = GetFirstChild (i); child; child = GetNextChild (i))
 		if (child->GetType () != gcp::BracketsType)
 			nb++;
-	if (nb < 2)
-		delete this;
-	else
-		Align ();
+	Align ();
 }
 
 std::string gcpGroup::Name ()
