@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/3d/document.h 
+ * programs/3d/document.h
  *
  * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -26,19 +26,22 @@
 #define GC3D_DOCUMENT_H
 
 #include <gcu/macros.h>
-#include <gcu/chem3ddoc.h>
+#include <gcugtk/chem3ddoc.h>
 
-using namespace gcu;
+namespace gcu {
+class Window;
+}
 
 class gc3dApplication;
 
-class gc3dDocument: public Chem3dDoc
+class gc3dDocument: public gcugtk::Chem3dDoc
 {
 public:
 	gc3dDocument (gc3dApplication *App);
 	virtual ~gc3dDocument ();
 
 	void Load (char const *uri, char const *mime_type);
+	gcu::Window *GetWindow ();
 };
 
 #endif	//	GC3D_DOCUMENT_H
