@@ -40,7 +40,6 @@
 using namespace gcu;
 using namespace std;
 
-map<string, GChemTableCurve*> curves;
 GObject *Copied;
 
 void on_show_curve (GObject *obj, char const* name)
@@ -48,11 +47,11 @@ void on_show_curve (GObject *obj, char const* name)
 	GChemTableApp *App = reinterpret_cast<GChemTableApp*> (g_object_get_data (obj, "app"));
 	if (App == NULL)
 		return;
-	GChemTableCurve *curve = curves[name];
-	if (curve)
-		gtk_window_present (curve->GetWindow ());
+	Dialog *dlg = (name)? App->GetDialog (name): NULL;
+	if (dlg)
+		dlg->Present ();
 	else
-		curves[name] = new GChemTableCurve (App, name);
+		new GChemTableCurve (App, name);
 }
 
 static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData *selection_data,  guint info, GogGraph *graph)
@@ -407,7 +406,7 @@ GChemTableCurve::GChemTableCurve (GChemTableApp *App, char const *name):
 		gog_object_add_by_name (obj, "Label", label);
 		gtk_window_set_title (dialog, _("Melting point"));
 	} else if (!strcmp (name, "bp")) {
-		ydata = gct_data_vector_get_from_name (_("Ebullition temperature"));
+		ydata = gct_data_vector_get_from_name (_("Boiling temperature"));
 		obj = gog_object_get_child_by_role (GOG_OBJECT (chart),
 				gog_object_find_role_by_name (GOG_OBJECT (chart), "Y-Axis"));
 		data = go_data_scalar_str_new (_("Boiling point"), FALSE);
@@ -443,7 +442,6 @@ GChemTableCurve::~GChemTableCurve ()
 {
 	if (m_Guru)
 		gtk_widget_destroy (m_Guru);
-	curves.erase (m_Name);
 }
 
 void GChemTableCurve::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext *context, G_GNUC_UNUSED int page) const
