@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/gchemtable-curve.h 
+ * programs/gchemtable-curve.h
  *
- * Copyright (C) 2005-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,14 +25,14 @@
 #ifndef GCHEMTABLE_CURVE_H
 #define GCHEMTABLE_CURVE_H
 
-#include <gcu/dialog.h>
-#include <gcu/printable.h>
+#include <gcugtk/dialog.h>
+#include <gcugtk/printable.h>
 #include <string>
 #include "gchemtable-app.h"
 
 using namespace gcu;
 
-class GChemTableCurve: public Dialog, public Printable
+class GChemTableCurve: public gcugtk::Dialog, public gcugtk::Printable
 {
 public:
 	GChemTableCurve (GChemTableApp *App, char const *name);
@@ -51,6 +51,7 @@ public:
 	void ClearGuru () {m_Guru = NULL;}
 	void SaveAsImage (std::string const &filename, char const *mime_type, unsigned width, unsigned height) const;
 	static void OnSize (GChemTableCurve *curve, GtkAllocation *allocation);
+	static bool OnMotion (GChemTableCurve *curve, GdkEventMotion *event);
 
 private:
 	std::string m_Name;
