@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/gchemtable-main.cc 
+ * programs/gchemtable-main.cc
  *
  * Copyright (C) 2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -24,9 +24,6 @@
 
 #include "config.h"
 #include "gchemtable-app.h"
-#include <goffice/goffice.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
 #include <libintl.h>
 
 using namespace gcu;
@@ -34,6 +31,7 @@ using namespace gcu;
 int main (int argc, char *argv[])
 {
 	textdomain (GETTEXT_PACKAGE);
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	gtk_init (&argc, &argv);
 
 	new GChemTableApp ();
@@ -41,7 +39,7 @@ int main (int argc, char *argv[])
 	GSList *l = NULL;
 	l = g_slist_append (l, (void *) "GOffice_plot_xy");
 	l = g_slist_append (l, (void *) "GOffice_reg_linear");
-	go_plugins_init (NULL, NULL, l, NULL, FALSE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, l, NULL, FALSE, GO_TYPE_PLUGIN_LOADER_MODULE);
 	g_slist_free (l);
 
 	gtk_main();
